'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-bdeef4f4.js');
const defaultIconPack = require('./default-icon-pack-0ea0e986.js');
const index$1 = require('./index-dbc5b08f.js');
const store = require('./store-d570e98c.js');
const versionTwoApis = require('./versionTwoApis-9c9006ae.js');
require('./default-language-4c779255.js');

const dyteCameraToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}";

const DyteCameraToggle = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.stateUpdate = index.createEvent(this, "dyteStateUpdate", 7);
    this.videoUpdateListener = ({ videoEnabled }) => {
      this.videoEnabled = videoEnabled;
    };
    this.mediaPermissionErrorListener = ({ kind, message }) => {
      if (kind === 'video') {
        this.cameraPermission = message;
      }
    };
    /** Variant */
    this.variant = 'button';
    /** Icon pack */
    this.iconPack = defaultIconPack.defaultIconPack;
    /** Language */
    this.t = index$1.useLanguage();
    this.videoEnabled = false;
    this.canProduceVideo = false;
    this.cameraPermission = 'NOT_REQUESTED';
    this.toggleCamera = () => {
      var _a;
      if (this.hasPermissionError()) {
        this.stateUpdate.emit({ activePermissionsMessage: true });
        store.state.activePermissionsMessage = true;
        return false;
      }
      const self = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self;
      if (self == null || !this.canProduceVideo) {
        return;
      }
      if (self.videoEnabled) {
        self.disableVideo();
      }
      else {
        self.enableVideo();
      }
    };
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a, _b;
    (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.removeListener('videoUpdate', this.videoUpdateListener);
    (_b = this.meeting) === null || _b === void 0 ? void 0 : _b.self.removeListener('mediaPermissionError', this.mediaPermissionErrorListener);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      const self = meeting.self;
      this.canProduceVideo = versionTwoApis.canProduce(versionTwoApis.ProduceType.Video, self.permissions);
      this.cameraPermission = self.mediaPermissions.video || 'NOT_REQUESTED';
      this.videoEnabled = self.videoEnabled;
      self.addListener('videoUpdate', this.videoUpdateListener);
      self.addListener('mediaPermissionError', this.mediaPermissionErrorListener);
    }
  }
  hasPermissionError() {
    return this.cameraPermission !== 'NOT_REQUESTED' && this.cameraPermission !== 'ACCEPTED';
  }
  getState() {
    let tooltipLabel = '';
    let label = '';
    let icon = '';
    let classList = {};
    let hasError = this.hasPermissionError();
    if (this.videoEnabled && !hasError) {
      label = this.t('video_on');
      icon = this.iconPack.video_on;
    }
    else {
      label = this.t('video_off');
      icon = this.iconPack.video_off;
      classList['red-icon'] = true;
    }
    if (this.cameraPermission === 'COULD_NOT_START') {
      tooltipLabel = this.t('Unable to start camera');
    }
    else if (this.cameraPermission === 'SYSTEM_DENIED') {
      tooltipLabel = this.t('perm_sys_denied');
    }
    else if (this.cameraPermission === 'DENIED') {
      tooltipLabel = this.t('perm_browser_denied');
    }
    else {
      tooltipLabel = this.videoEnabled ? this.t('Disable Camera') : this.t('Enable Camera');
    }
    return { tooltipLabel, label, icon, classList, showWarning: hasError };
  }
  render() {
    if (!this.canProduceVideo) {
      return null;
    }
    const { tooltipLabel, label, icon, classList, showWarning } = this.getState();
    return (index.h(index.Host, { title: label }, index.h("dyte-tooltip", { kind: "block", label: tooltipLabel, part: "tooltip" }, index.h("dyte-controlbar-button", { part: "controlbar-button", size: this.size, iconPack: this.iconPack, class: classList, variant: this.variant, label: label, icon: icon, onClick: this.toggleCamera, showWarning: showWarning, disabled: showWarning }))));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DyteCameraToggle.style = dyteCameraToggleCss;

exports.dyte_camera_toggle = DyteCameraToggle;
