import { Component, Host, h, Prop, State } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { getInitials } from './utils';
import { formatName } from '../../utils/string';
/**
 * Avatar component which renders a participant's image or their initials.
 */
export class DyteAvatar {
  constructor() {
    /** Avatar type */
    this.variant = 'circular';
    /** Icon pack */
    this.iconPack = defaultIconPack;
    this.imageState = 'loading';
    this.getAvatar = () => {
      var _a;
      const name = formatName(((_a = this.participant) === null || _a === void 0 ? void 0 : _a.name) || '');
      let picture;
      if (this.participant != null && 'picture' in this.participant) {
        picture = this.participant.picture;
      }
      if (picture && picture.length > 0 && this.imageState !== 'errored') {
        return (h("div", { class: "image-ctr" },
          this.imageState === 'loading' && h("dyte-spinner", null),
          h("img", { src: picture, class: { loaded: this.imageState === 'loaded' }, loading: "lazy", title: name, onLoad: () => (this.imageState = 'loaded'), onError: () => (this.imageState = 'errored'), part: "image" })));
      }
      const initials = getInitials(name);
      return (h("div", { class: "initials", title: name, part: "initials" }, initials));
    };
  }
  render() {
    return h(Host, null, this.getAvatar());
  }
  static get is() { return "dyte-avatar"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-avatar.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-avatar.css"]
  }; }
  static get properties() { return {
    "participant": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Peer",
        "resolved": "({ readonly id: string; readonly name: string; readonly picture: string; readonly clientSpecificId: any; readonly waitlistStatus: \"accepted\" | \"waiting\" | \"rejected\" | \"none\"; readonly preview: Pick<LocalMediaHandler, \"audioTrack\" | \"videoTrack\" | \"audioEnabled\" | \"videoEnabled\">; readonly role: any; readonly userId: string; readonly organizationId: string; readonly supportsRemoteControl: boolean; readonly device: DeviceConfig; readonly audioTrack: MediaStreamTrack; readonly rawAudioTrack: MediaStreamTrack; readonly addAudioMiddleware: (audioMiddleware: AudioMiddleware) => Promise<{ success: boolean; message: string; }>; readonly removeAudioMiddleware: (audioMiddleware: AudioMiddleware) => Promise<{ success: boolean; message: string; }>; readonly videoTrack: MediaStreamTrack; readonly rawVideoTrack: MediaStreamTrack; readonly addVideoMiddleware: (videoMiddleware: VideoMiddleware) => Promise<{ success: boolean; message: string; }>; readonly removeVideoMiddleware: (videoMiddleware: VideoMiddleware) => Promise<{ success: boolean; message: string; }>; readonly screenShareTracks: { audio?: MediaStreamTrack; video?: MediaStreamTrack; }; readonly audioEnabled: boolean; readonly videoEnabled: boolean; readonly screenShareEnabled: boolean; readonly mediaPermissions: { audio?: \"NOT_REQUESTED\" | \"ACCEPTED\" | \"DENIED\" | \"SYSTEM_DENIED\" | \"COULD_NOT_START\"; video?: \"NOT_REQUESTED\" | \"ACCEPTED\" | \"DENIED\" | \"SYSTEM_DENIED\" | \"COULD_NOT_START\"; screenshare?: \"NOT_REQUESTED\" | \"ACCEPTED\" | \"DENIED\" | \"SYSTEM_DENIED\" | \"COULD_NOT_START\"; }; readonly permissions: DytePermissionsPreset | DytePermissionsPresetV1; readonly suggestedTheme: DyteThemePresetV1 | DyteThemePreset; readonly roomJoined: boolean; readonly setName: (name: string) => void; readonly setupTracks: (options?: { video?: boolean; audio?: boolean; }) => Promise<void>; readonly enableAudio: () => Promise<void>; readonly enableVideo: () => Promise<void>; readonly enableScreenShare: () => Promise<void>; readonly disableAudio: () => Promise<void>; readonly disableVideo: () => Promise<void>; readonly disableScreenShare: () => Promise<void>; readonly enablePreview: (options?: { audio?: boolean; video?: boolean; }) => Promise<void>; readonly disablePreview: (options?: { audio?: boolean; video?: boolean; }) => Promise<void>; readonly getCurrentDevices: () => { audio: MediaDeviceInfo; video: MediaDeviceInfo; speaker: MediaDeviceInfo; }; readonly getAudioDevices: () => MediaDeviceInfo[]; readonly getVideoDevices: () => MediaDeviceInfo[]; readonly getSpeakerDevices: () => MediaDeviceInfo[]; readonly getDeviceById: (deviceId: string, kind: \"audio\" | \"video\" | \"speaker\") => MediaDeviceInfo; readonly getAllDevices: () => MediaDeviceInfo[]; readonly setIsPinned: (isPinned: boolean, emitEvent?: boolean) => void; readonly isPinned: boolean; readonly pin: () => Promise<WebsocketMessage>; readonly unpin: () => Promise<WebsocketMessage>; readonly setDevice: (device: MediaDeviceInfo, preview?: boolean) => Promise<void>; readonly emit: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", ...args: any[]) => boolean; readonly on: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => void) => DyteSelf; readonly addListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly off: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly once: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly prependListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly prependOnceListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly removeListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly removeAllListeners: (event?: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => DyteSelf; readonly listeners: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => Function[]; readonly listenerCount: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => number; readonly setMaxListeners: (n: number) => DyteSelf; readonly getMaxListeners: () => number; readonly rawListeners: (eventName: string | symbol) => Function[]; readonly eventNames: () => (string | symbol)[]; }) | ({ readonly id: string; readonly userId: string; readonly name: string; readonly picture: string; readonly isHost: boolean; readonly clientSpecificId?: string; readonly flags: { [key: string]: string | boolean; }; readonly device: DeviceConfig; readonly videoTrack: MediaStreamTrack; readonly audioTrack: MediaStreamTrack; readonly screenShareTracks: { audio: MediaStreamTrack; video: MediaStreamTrack; }; readonly videoEnabled: boolean; readonly audioEnabled: boolean; readonly screenShareEnabled: boolean; readonly supportsRemoteControl: boolean; readonly setVideoEnabled: (videoEnabled: boolean, emitEvent?: boolean) => void; readonly setAudioEnabled: (audioEnabled: boolean, emitEvent?: boolean) => void; readonly setScreenShareEnabled: (screenShareEnabled: boolean, emitEvent?: boolean) => void; readonly pin: () => Promise<WebsocketMessage>; readonly unpin: () => Promise<WebsocketMessage>; readonly setIsPinned: (isPinned: boolean, emitEvent?: boolean) => void; readonly disableAudio: () => Promise<void>; readonly kick: () => Promise<void>; readonly disableVideo: () => Promise<void>; readonly isPinned: boolean; readonly emit: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", ...args: any[]) => boolean; readonly on: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => void) => DyteParticipant; readonly addListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly off: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly once: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly prependListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly prependOnceListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly removeListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly removeAllListeners: (event?: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => DyteParticipant; readonly listeners: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => Function[]; readonly listenerCount: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => number; readonly setMaxListeners: (n: number) => DyteParticipant; readonly getMaxListeners: () => number; readonly rawListeners: (eventName: string | symbol) => Function[]; readonly eventNames: () => (string | symbol)[]; })",
        "references": {
          "Peer": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Participant object"
      }
    },
    "variant": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "AvatarVariant",
        "resolved": "\"circular\" | \"hexagon\" | \"square\"",
        "references": {
          "AvatarVariant": {
            "location": "local"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Avatar type"
      },
      "attribute": "variant",
      "reflect": true,
      "defaultValue": "'circular'"
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ people: string; chat: string; poll: string; participants: string; rocket: string; call_end: string; share: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_down: string; chevron_up: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; full_screen_maximize: string; full_screen_minimize: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; vertical_scroll_disabled: string; image_off: string; disconnected: string; wand: string; recording: string; subtract: string; stop_recording: string; warning: string; pin: string; pin_off: string; spinner: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    }
  }; }
  static get states() { return {
    "imageState": {}
  }; }
}
